Data Dictionary HTML documentation

Search:

Keywords (of length > 1) separated by spaces

Returns elements with a path matching all keywords or a description matching most keywords

Ex:

bar code desc

➔barometry/code/description

➔barometry/code/library/description

✕barometry/code

✕barometry/gauge/type/description

▼
Data type:

One keyword

Returns elements with a type matching whole or part of keyword

Ex:

2D

➔FLT_2D

➔INT_2D

...

Coords:

Keywords separated by spaces indicating either the coordinate followed by ':', its value, or both.

Returns elements having coordinates matching all conditions

Ex:

3:

➔All elements with at least 3 coordinates

phi

➔All elements with a coordinate same as some element phi

1:voltage/time

➔All elements where 1st coordinate same as some element voltage/time